@@ -258,12 +258,19 @@ impl fmt::Display for ApiError {
     }
 }
 
+
 impl From<StatusCode> for ApiError {
     fn from(s: StatusCode) -> Self {
         Self::new(s)
     }
 }
 
+impl From<ApiError> for HttpApiProblem {
+    fn from(error: ApiError) -> Self {
+        error.into_http_api_problem()
+    }
+}
+
 impl From<io::Error> for ApiError {
     fn from(error: io::Error) -> Self {
         ApiError::with_message_and_cause(
